@@ -62,7 +62,9 @@
 # if defined(HAVE_ALIB_H)
 #  define HPUX_MIXER
 # else
+#ifdef __GNUC__
 #  warning ** YOU NEED to have libAlib installed to use the HP-UX-Mixer **
+#endif
 # endif // HAVE_ALIB_H
 #endif // hpux
 
@@ -86,8 +88,22 @@
 #include "mixer_pulse.cpp"
 #endif
 
+// OSS 3 / 4
 #if defined(OSS_MIXER)
 #include "mixer_oss.cpp"
+
+#if !defined(__NetBSD__) && !defined(__OpenBSD__)
+#include <sys/soundcard.h>
+#else
+#include <soundcard.h>
+#endif
+#if !defined(__FreeBSD__) && SOUND_VERSION >= 0x040000
+#define OSS4_MIXER
+#endif
+#endif
+
+#if defined(OSS4_MIXER)
+#include "mixer_oss4.cpp"
 #endif
 
 #if defined(HPUX_MIXER)
@@ -121,6 +137,10 @@ MixerFactory g_mixerFactories[] = {
     { OSS_getMixer, OSS_getDriverName },
 #endif
 
+#if defined(OSS4_MIXER)
+    { OSS4_getMixer, OSS4_getDriverName },
+#endif
+
 #if defined(HPUX_MIXER)
     { HPUX_getMixer, HPUX_getDriverName },
 #endif
